<?php

namespace App\Http\Controllers\API;

use App\Http\Requests\API\CreateUserAPIRequest;
use App\Http\Requests\API\UpdateUserAPIRequest;
use App\Models\User;
use App\Repositories\UserRepository;
use Illuminate\Http\Request;
use App\Http\Controllers\AppBaseController;
use Response;
use Hash;
use Validator;
use Auth;
use Illuminate\Support\Str;
use Laravel\Sanctum\PersonalAccessToken;
require_once('../external/AfricasTalkingGateway.php');
use DB;

/**
 * Class UserController
 * @package App\Http\Controllers\API
 */

class UserAPIController extends AppBaseController
{
    /** @var  UserRepository */
    private $userRepository;

    public function __construct(UserRepository $userRepo)
    {
        $this->userRepository = $userRepo;
    }

    /**
     * Display a listing of the User.
     * GET|HEAD /users
     *
     * @param Request $request
     * @return Response
     */
    /**
 * @OA\Info(
 *    title="APIs For Thrift Store",
 *    version="1.0.0",
 * ),
 *   @OA\SecurityScheme(
 *       securityScheme="bearerAuth",
 *       in="header",
 *       name="bearerAuth",
 *       type="http",
 *       scheme="bearer",
 *       bearerFormat="JWT",
 *    ),
 */
    public function index(Request $request)
    {
        $users =User::with(['district','country'])->get();
        $response = [
            'success'=>true,
            'data'=> $users,
            'message'=> 'Users retrieved successfully'
         ];
         return response()->json($response,200);
    }

    /**
     * Store a newly created User in storage.
     * POST /users
     *
     * @param CreateUserAPIRequest $request
     *
     * @return Response
     */

    public function sendSms($content,$tell){



        $rand = "3242";

        $message    = $content;
        $apikey = "32e6988167f57dc60e425bb7ff9808f6fa322d017c2341be040c6bf9f881bb3c";
        $username='medaasi';

        $gateway    = new \AfricasTalkingGateway($username, $apikey);
       try
       {
         $recipients='+'.$tell;
         //$recipients='+256779815657';
         $results = $gateway->sendMessage($recipients, $message);

       }
       catch ( \AfricasTalkingGatewayException $e )
       {
        echo "Encountered an error while sending: ".$e->getMessage();
      }


    }
    public function store(CreateUserAPIRequest $request)
    {
        // $validator = Validator::make($request->all(),User::$rules);
        // if($validator->fails()){
        //     $response = [
        //         'success'=>false,
        //         'message'=>$validator->errors()
        //     ];
        //     return response()->json($response,400);

        // }

        //existing user
        $existing_user = User::where('email',$request->input('email'))->orWhere('phone',$request->phone)->first();
        if(!$existing_user){
            $user = new User();
            $user->first_name = $request->first_name;
            $user->last_name = $request->last_name;
            $user->username = $request->last_name . " " .$request->first_name;
            $user->email = $request->email;
            $user->country_id = (int)$request->country_id;
            $user->district_id = (int)$request->district_id;
            $user->phone = $request->phone;
            $user->isAdmin = 0;
            $user->image_url = $request->image_url;
            $user->user_type = $request->user_type;
            $password = $request->password;
            $user->password = Hash::make($password);

            //assign a user a role depending on the user type
             if($user->user_type=='Admin'){
              $user->assignRole('admin');
             }

             elseif($user->user_type=='seller'){
              $user->assignRole('seller');
             }
             elseif($user->user_type=='vendor'){
              $user->assignRole('vendor');
             }
             elseif($user->user_type=='buyer'){
              $user->assignRole('buyer');
             }
             else{
              $user->assignRole('farmer');

             }

             $user->save();
             $user_token = Str::random(60);
             $success['token'] = $user->createToken($user_token)->plainTextToken;
             $success['id'] = $user->id;
             $success['first_name'] = $user->first_name;
             $success['last_name'] = $user->last_name;
             $success['email'] = $user->email;
             $success['phone'] = $user->phone;
             $success['user_type'] = $user->user_type;
             $success['image_url'] = $user->image_url;
             $success['country'] = $user->country->name;
             $success['district'] = $user->district->name;

             $user = User::find($user->id);

             $user->image_url = \App\Models\ImageUploader::upload($request->file('image_url'),'users');
             $user->save();

             $opt = rand(1000, 9999);
             $user->otp = $opt;
             $user->is_verified_otp = false;
             $user->save();

             $content = "Digi Farmer App verification OTP - ". $opt ;
             $this->sendSms($content,$request->phone);
             $response = [
                'success'=>true,
                'data'=> $success,
                'message'=> 'Account created successfully'
             ];

        return response()->json($response,200);

        }
        else{
            $response = [
                'success'=>false,
                'message'=> 'User with this email or phone number already exists'
             ];
             return response()->json($response,403);
        }




    }


    public function verifyUserOtp(Request $request){

        $check_user_otp = User::where('otp',$request->otp)->first();

        if($check_user_otp){
          $check_user_otp->is_verified_otp = true;
          $check_user_otp->save();
          $response = [
            'success'=>true,
            'message'=> 'Phone number verified successfully'
         ];
         return response()->json($response,200);

        }
        else{

          $response = [
            'success'=>false,
            'message'=> 'Invalid Otp'
         ];
         return response()->json($response);
        }



    }


    // public function login(Request $request){

    //      if (!Auth::attempt($request->only('phone', 'password'))) {
    //          return response()->json([ 'message' => 'Invalid login details' ], 401);
    //        }

    //      $token = $user->createToken('auth_token')->plainTextToken;
    //     return response()->json(['access_token' => $token,'token_type' => 'Bearer Token',    ]);
    // }

    public function login(Request $request)
    {
        if(Auth::attempt(['phone' => $request->phone ,'password' => $request->password])){
            $user = Auth::user();
            $success['token'] =  $user->createToken('Farmer')->plainTextToken;
           
                 $success['email'] =  $user->email;
            $success['phone'] =  $user->phone;
            $success['first_name'] = $user->first_name;
             $success['last_name'] = $user->last_name;
             $success['user_type'] = $user->user_type;
             $success['image_url'] = $user->image_url;
             $success['country'] = $user->country->name;
             $success['district'] = $user->district->name;


            return $this->sendResponse($success, 'User login successfully.');
        }
        else{

            $response = [
                'success'=>false,
                'message'=> 'Invalid credentials'
             ];
             return response()->json($response);
        }
    }



    public function checkPhoneNumber(Request $request){


       // $user_phone_number = User::where('phone', $request['phone'])->firstOrFail();
       if(User::where('phone', $request['phone'])->first()){
        $response = [
            'success'=>true,
            'message'=> 'Phone number verified successfully'
         ];
         return response()->json($response,200);
       }
        else{

        $response = [
            'success'=>false,
            'message'=> 'Phone number does not exist'
         ];
         return response()->json($response);
       }

   }


   public function checkPassword(Request $request,$phone){


    $user_password = User::where('phone',$phone)->first();
    if(Hash::check($request->password, $user->password)) {
        return response()->json(['status'=>'true','message'=>'User password exists']);
    } else {
        return response()->json(['status'=>'false', 'message'=>'Password doesnt exist']);
    }


}


    public function loggedInUser(Request $request){
         return $request->user();
    }



           /**
     * Display the specified User.
     * GET|HEAD /users/{id}
     *
     * @param int $id
     *
     * @return Response
     */
    public function show($id)
    {
        /** @var User $user */
        $user = User::find($id);
        $success['username'] = $user->username;
        $success['first_name'] = $user->first_name;
        $success['last_name'] = $user->last_name;
        $success['email'] = $user->email;
        $success['phone'] = $user->phone;
        $success['user_type'] = $user->user_type;
        $success['image_url'] = $user->image_url;
        $success['country'] = $user->country->name;
        $success['district'] = $user->district->name;
        $success['email_verified_at'] = $user->email_verified_at;
        $success['created_at'] = $user->created_at;


        if (empty($user)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $success,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }

    /**
     * Update the specified User in storage.
     * PUT/PATCH /users/{id}
     *
     * @param int $id
     * @param UpdateUserAPIRequest $request
     *
     * @return Response
     */
    public function update($id,UpdateUserAPIRequest $request)
    {
        $user = User::find($id);

        if (empty($user)) {
            $response = [
                'success'=>false,
                'message'=> 'User does not exist'
               ];
               return response()->json($response,200);

        }

        if( $user){

            $user->first_name = $request->first_name;
            $user->last_name = $request->last_name;
            $user->email = $request->email;
            $user->country_id = (int)$request->country_id;
            $user->phone = $request->phone;
            $user->image_url = $request->image_url;
            $password = $request->password;
            $user->password = Hash::make($password);

            if(!empty($request->file('image_url'))){
                $user->image_url = \App\Models\ImageUploader::upload($request->file('image_url'),'users');
            }
            $user->save();

            $response = [
                'success'=>true,
                'data'=> $success,
                'message'=> 'User account created successfully'
             ];

        return response()->json($response,200);

        }
        else{
            $response = [
                'success'=>false,
                'message'=> 'User with this email already exists'
             ];
             return response()->json($response,403);
        }



        return $this->sendResponse($user->toArray(), 'User updated successfully');
    }

    /**
     * Remove the specified User from storage.
     * DELETE /users/{id}
     *
     * @param int $id
     *
     * @throws \Exception
     *
     * @return Response
     */
    public function destroy($id)
    {
        /** @var User $user */
        $user = $this->userRepository->find($id);

        if (empty($user)) {
            return $this->sendError('User not found');
        }

        $user->delete();

        return $this->sendSuccess('User deleted successfully');
    }

    //user logout
    public function userLogOut(Request $request){
        {


            // Get bearer token from the request
           $accessToken = $request->bearerToken();

           // Get access token from database
           $token = PersonalAccessToken::findToken($accessToken);

           // Revoke token
           $token->delete();

            $response = [
                'success'=>true,
                'message'=> 'You logged out of your account'
             ];

        return response()->json($response,200);
        }
    }
    
    public function categ($id)
    {
        
      
        $categories = DB::table('productcateg')->where('vendorcategid', $id)->get();
        //$products = DB::table('product')->get();

        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }
    
    
     public function productts($id)
    {
        
      
        $categories = DB::table('product')->where('categid', $id)->get();
        //$products = DB::table('product')->get();

        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }
    

  
     public function vendors($id)
    {
        
      
        $productvendors = DB::table('productvendors')->where('productid','=', $id)
         ->leftjoin('users', 'users.id', '=', 'productvendors.vendorid')
         ->leftjoin('product', 'productvendors.productid', '=',   'product.id')
         ->get();
         
         //dump($productvendors);
         

        if (empty($productvendors)) {
            return $this->sendError('Vendors not found');
        }
        $response = [
            'success'=>true,
            'data'=> $productvendors,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }
    
    
    
  //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
  
  
  
    
     public function stores($id)
    {
        
        $categories = DB::table('invstore')->where('idcompany','=', $id)->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }
    
  
    
 public function addstore(Request $request)
    {
         $goods = DB::table('invgoods')->groupBy('name')->get();
  
        DB::table('invstore')->insert([
            'storename' => $request->input('storename') , 
            'description' => $request->input('storename'), 
            'idcompany' => $request->input('idcompany'), 
            'date' => "12/02/2022" 
             ]  );
        
  $categories = DB::table('invstore')->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];
           
           
   $lstore = DB::table('invstore')->orderBy('id', 'desc')->pluck('id')->first();
$goods = DB::table('invgoods')->groupBy('name')->get();

//var_dump($goods);

//$storeid='5';
/*
foreach ($goods as $good) {
  if (DB::table('invgoods')->where([['idstore','=',$storeid],['idstore','=',$storeid] ])->exists()){
      
      }else{
         
            DB::table('invgoods')->insert([
            'name' => $good->name , 
            'description' =>$good->description,
            'buyingprice' => $good->buyingprice , 
            'sellingprice' => $good->sellingprice,
            'idstore' => $lstore,
            'stock' =>"0" , 
             ]  ); 
     } 
}     
*/
        return response()->json($lstore,200);

    }
    
    
    
    
       
 public function addcustomer(Request $request)
    {
  
        DB::table('invcustomers')->insert([
            'type' => $request->input('type') , 
            'customername' => $request->input('name'), 
             ]  );
        
  $categories = DB::table('invcustomers')->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);

    } 
    
    

    
    
    public function stock($id)
    {
        if($id=='all-stores'){
            $goods = DB::table('invgoods')->groupBy('name')
            ->selectRaw('*, sum(stock) as stock')
            ->get();
        $stock = DB::table('invgoods')->sum('stock');
        $pprice = DB::table('invgoods')->selectRaw('sum(stock * buyingprice) as totalprice')->get();
        $sprice = DB::table('invgoods')->selectRaw('sum(stock * sellingprice) as totalprice')->get();
        }else{
            $goods = DB::table('invgoods')->where('idstore','=',$id)->get();
            $stock = DB::table('invgoods')->where('idstore','=',$id)->sum('stock');
            $pprice = DB::table('invgoods')->where('idstore','=',$id)->selectRaw('sum(stock * buyingprice) as totalprice')->get();
            $sprice = DB::table('invgoods')->where('idstore','=',$id)->selectRaw('sum(stock * sellingprice) as totalprice')->get();
        }
        
        if (empty($goods)) {
            return $this->sendError('User not found');
        }
      
        $totals['totalstock'] = $stock ;
        $totals['totalpurchase'] =$pprice;
        $totals['totalsellinge'] =$sprice;
        $response = [
            'success'=>true,
            'data'=> $goods,
            'data2'=> $totals,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }   
    
    
    
    public function item($id , $companyid)
    {
        
        
        if($id=='all-stores'){
            $goods = DB::table('invstock')->where([['type','=','out'],['idcompany','=',$companyid]])->groupBy('name')
            ->selectRaw('*, sum(newquantity) as stock , sum(newquantity * price) as purprice , sum(newquantity * buyingprice) as costprice ,  sum((newquantity * price ) - (newquantity * buyingprice)) as profit ')
            ->get();
        $stock = DB::table('invstock')->where([['type','=','out'],['idcompany','=',$companyid]])->sum('newquantity');
        $pprice = DB::table('invstock')->where([['type','=','out'],['idcompany','=',$companyid]])->selectRaw('sum(newquantity * price) as totalprice')->get();
       $sprice = DB::table('invstock')->where([['type','=','out'],['idcompany','=',$companyid]])->selectRaw('sum(newquantity * buyingprice) as totalprice')->get();
        $profit = DB::table('invstock')->where([['type','=','out'],['idcompany','=',$companyid]])->selectRaw('sum((newquantity * price ) - (newquantity * buyingprice)) as profit')->get();
        
        }else{
            
            $goods = DB::table('invstock')->where([['type','=','out'],['idstore','=',$id],['idcompany','=',$companyid]])->get();
            $stock = DB::table('invstock')->where([['type','=','out'],['idstore','=',$id],['idcompany','=',$companyid]])->sum('newquantity');
            $pprice = DB::table('invstock')->where([['type','=','out'],['idstore','=',$id],['idcompany','=',$companyid]])->selectRaw('sum(newquantity * price) as totalprice')->get();
            $sprice = DB::table('invstock')->where([['type','=','out'],['idstore','=',$id],['idcompany','=',$companyid]])->selectRaw('sum(newquantity * buyingprice) as totalprice')->get();
             $profit = DB::table('invstock')->where([['type','=','out'],['idstore','=',$id],['idcompany','=',$companyid]])->selectRaw('sum((newquantity * price ) - (newquantity * buyingprice)) as profit')->get();
            //newquantity	type	supliername	customername	comment	name	price	buyingprice	idcompany	date
        }
        
        if (empty($goods)) {
            return $this->sendError('User not found');
        }
      
        $totals['totalstock'] = $stock ;
        $totals['totalpurchase'] =$pprice['0']->totalprice;
        $totals['totalsellinge'] =$sprice['0']->totalprice;
        $totals['profit'] =$profit['0']->profit;
        $response = [
            'success'=>true,
            'data'=> $goods,
            'data2'=> $totals,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }       
    
  
    public function bcustom($id)
    {
        
        
        if($id=='all-stores'){
            $goods = DB::table('invstock')->where('customername','!=','0')->groupBy('customername')
            ->selectRaw('*, sum(newquantity) as stock , sum(newquantity * price) as purprice , sum(newquantity * buyingprice) as costprice ,  sum((newquantity * price ) - (newquantity * buyingprice)) as profit ')
            ->get();
        //$stock = DB::table('invgoods')->sum('stock');
        //$pprice = DB::table('invgoods')->selectRaw('sum(stock * buyingprice) as totalprice')->get();
       // $sprice = DB::table('invgoods')->selectRaw('sum(stock * sellingprice) as totalprice')->get();
        }else{
            $goods = DB::table('invgoods')->where('idstore','=',$id)->get();
            $stock = DB::table('invgoods')->where('idstore','=',$id)->sum('stock');
            $pprice = DB::table('invgoods')->where('idstore','=',$id)->selectRaw('sum(stock * buyingprice) as totalprice')->get();
            $sprice = DB::table('invgoods')->where('idstore','=',$id)->selectRaw('sum(stock * sellingprice) as totalprice')->get();
        }
        
        if (empty($goods)) {
            return $this->sendError('User not found');
        }
      
        //$totals['totalstock'] = $stock ;
       // $totals['totalpurchase'] =$pprice;
        //$totals['totalsellinge'] =$sprice;
        $response = [
            'success'=>true,
            'data'=> $goods,
            //'data2'=> $totals,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }    
  
  
      public function bbcustom($id , $companyid)
    {
        
  if($id=='all-stores'){
 
            $customers = DB::table('invstock')->where([['customername','!=','0'],['idcompany','=',$companyid]])->groupBy('customername')->get();

             $goodv = array();
             $tot = array();
            
            for($i=0;$i<sizeof($customers);$i++){
                
              $goodds = DB::table('invstock')->where([['customername','=',$customers[$i]->customername],['idcompany','=',$companyid]])->groupBy('name')
              ->selectRaw('*, sum(newquantity) as stock , sum(newquantity * price) as purprice , sum(newquantity * buyingprice) as costprice ,  sum((newquantity * price ) - (newquantity * buyingprice)) as profit ')
              ->get();
              
              
            $pprice = DB::table('invstock')->where([['customername','=',$customers[$i]->customername],['idcompany','=',$companyid]])->selectRaw('sum(newquantity * price) as totalprice')->get();
            
            $stock = DB::table('invstock')->where([['customername','=',$customers[$i]->customername],['idcompany','=',$companyid]])->selectRaw('sum(newquantity) as stock')->get();
            
            $tot['totalprice'] = $pprice['0']->totalprice;
            $tot['stockk']  =$stock['0']->stock;
            $tot['customername'] = $customers[$i]->customername;
            
            $goodds[] =$tot;
            
            $goodv[] = $goodds;
  
            
            }

       
       
        }
        else{
            
           $customers = DB::table('invstock')->where([['customername','!=','0'],['idcompany','=',$companyid] , ['storeid','=',$id] ])->groupBy('customername')->get();

             $goodv = array();
             $tot = array();
            
            for($i=0;$i<sizeof($customers);$i++){
                
              $goodds = DB::table('invstock')->where([['customername','=',$customers[$i]->customername],['idcompany','=',$companyid], ['storeid','=',$id]])->groupBy('name')
              ->selectRaw('*, sum(newquantity) as stock , sum(newquantity * price) as purprice , sum(newquantity * buyingprice) as costprice ,  sum((newquantity * price ) - (newquantity * buyingprice)) as profit ')
              ->get();
              
              
            $pprice = DB::table('invstock')->where([['customername','=',$customers[$i]->customername],['idcompany','=',$companyid], ['storeid','=',$id]])->selectRaw('sum(newquantity * price) as totalprice')->get();
            
            $stock = DB::table('invstock')->where([['customername','=',$customers[$i]->customername],['idcompany','=',$companyid], ['storeid','=',$id]])->selectRaw('sum(newquantity) as stock')->get();
            
            $tot['totalprice'] = $pprice['0']->totalprice;
            $tot['stockk']  =$stock['0']->stock;
            $tot['customername'] = $customers[$i]->customername;
            
            $goodds[] =$tot;
            
            $goodv[] = $goodds;
  
            
            }
        }
        
        if (empty($customers)) {
            return $this->sendError('User not found');
        }
      

        $response = [
            'success'=>true,
            'data'=> $customers ,
            'data2'=> $goodv ,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }    
    
    public function goods($id , $idcompany)
    {
        if($id=='all-stores'){
            /*$goods = DB::table('invgoods')->where('idcompany',$idcompany)->groupBy('name')
            ->selectRaw('*, sum(stock) as stock')
            ->get();*/

            $goods = DB::table('invgoods')
            ->selectRaw('*, sum(stock) as stock')
            ->get();
            
            
        $stock = DB::table('invgoods')->where('idcompany',$idcompany)->sum('stock');
        $pprice = DB::table('invgoods')->where('idcompany',$idcompany)->selectRaw('sum(stock * buyingprice) as totalprice')->get();
        $sprice = DB::table('invgoods')->where('idcompany',$idcompany)->selectRaw('sum(stock * sellingprice) as totalprice')->get();
        }else{
           /* $goods = DB::table('invgoods')->where([['idstore','=',$id],['idcompany','=',$idcompany]])->get();*/

            $goods = DB::table('invgoods')->get();

            $stock = DB::table('invgoods')->where([['idstore','=',$id],['idcompany','=',$idcompany]])->sum('stock');
            $pprice = DB::table('invgoods')->where([['idstore','=',$id],['idcompany','=',$idcompany]])->selectRaw('sum(stock * buyingprice) as totalprice')->get();
            $sprice = DB::table('invgoods')->where([['idstore','=',$id],['idcompany','=',$idcompany]])->selectRaw('sum(stock * sellingprice) as totalprice')->get();
        }
        
        if (empty($goods)) {
            return $this->sendError('User not found');
        }
      
        $totals['totalstock'] = $stock ;
        $totals['totalpurchase'] =$pprice;
        $totals['totalsellinge'] =$sprice;
        $response = [
            'success'=>true,
            'data'=> $goods,
            'data2'=> $totals,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }     
    

 public function editgood(Request $request){
             DB::table('invgoods')->where('name',  $request->input('oname'))
             ->update(
                 array(
                     'name' =>$request->input('name'),
                     'description' =>$request->input('description'),
                     'buyingprice' =>$request->input('buyingprice'),
                     'sellingprice' =>$request->input('sellingprice'),
                      'unit' => $request->input('unit')
                     ));  
                     
        $categories = DB::table('invgoods')->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);               
                     
                     
 }
  

    
 public function addgoods(Request $request)
    {
  if($request->input('type') == "transfer" ){
          DB::table('invgoods')->where('id',  $request->input('productid'))->limit(1)->update(array('stock' =>(int) $request->input('oldstock') - (int)$request->input('stock') ));
          $stock = $request->input('stock');
  }
  else{
      $stock = 0;
  }
        DB::table('invgoods')->insert([
            'name' => $request->input('name') , 
            'description' => $request->input('description'),
            'buyingprice' => $request->input('buyingprice') , 
            'sellingprice' => $request->input('sellingprice'),
            'idstore' => $request->input('storeid'),    
            'idcompany' => $request->input('idcompany'),
            'unit' => $request->input('unit'),
            'stock' =>$stock , 
             ]  );
  
  $categories = DB::table('invgoods')->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);

    } 
    
    

    
    
    
    public function addstock(Request $request)
    {
  
  if($request->input('type')=='in'){
      
     $nstock = (int) $request->input('quantity') + (int)$request->input('newquantity');
       if($nstock>0){
     DB::table('invgoods')->where('id',  $request->input('productid'))->limit(1)->update(array('stock' => $nstock));  
      }
     
  
  }else{
      $nstock = (int) $request->input('quantity') - (int)$request->input('newquantity');
      if($nstock>0){
        DB::table('invgoods')->where('id',  $request->input('productid'))->limit(1)->update(array('stock' =>$nstock ));   
      }
      
  
  }
  if($nstock>0){
  
        DB::table('invstock')->insert([
            
            'storeid' => $request->input('storeid') , 
            'productid' => $request->input('productid'),
            'quantity' => $request->input('quantity') , 
            'newquantity' => $request->input('newquantity'),
            'type' => $request->input('type'),
            'supliername' => $request->input('supliername') , 
            'customername' => $request->input('customername'),
            'comment' => 'nn',
            'name' => $request->input('name'),
            'price' => $request->input('price'),
            'date' => $request->input('date'),
            'buyingprice' => $request->input('buyingprice'),
            'idcompany' => $request->input('idcompany'),
             
             ]  );
  }
  $categories = DB::table('invstock')->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);

    }   
    
  
     public function editstock(Request $request)
    {
  /*
  if($request->input('type')=='in'){
  DB::table('invgoods')->where('id',  $request->input('productid'))->limit(1)->update(array('stock' =>(int) $request->input('quantity') + (int)$request->input('newquantity') ));
  }else{
       DB::table('invgoods')->where('id',  $request->input('productid'))->limit(1)->update(array('stock' =>(int) $request->input('quantity') - (int)$request->input('newquantity') ));
  
  }*/
  
   DB::table('invstock')->where('id',  $request->input('id'))
             ->update(
                 array(
                        //'productid' => $request->input('productid'),
                        //'quantity' => $request->input('quantity') , 
                        'newquantity' => $request->input('newquantity'),
                        //'type' => $request->input('type'),
                        //'supliername' => $request->input('supliername') , 
                        //'customername' => $request->input('customername'),
                       // 'comment' => 'nn',
                        'name' => $request->input('name'),
                        //'price' => $request->input('price'),
                        //'date' => $request->input('date'),
                        'buyingprice' => $request->input('buyingprice'),
                     ));
  

        
  $categories = DB::table('invstock')->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);

    }  
  
  
  
  
    
    public function itemr()
    {
        
        $goods = DB::table('invstock')->get();
        if (empty($goods)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $goods,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }   
    
    
    public function documentt($id)
    {
        
        if($id=='all-stores' || $id=='allstores'  ){
            $goods = DB::table('invstock')->orderBy('id', 'desc')->get();
        }else{
            $goods = DB::table('invstock')->where('storeid',  $id)->orderBy('id', 'desc')->get();
            
        }  
        
        if (empty($goods)) {
        return $this->sendError('User not found');
    }
    $response = [
        'success'=>true,
        'data'=> $goods,
        'message'=> 'User retrieved successfully'
       ];
       
        return response()->json($response,200);
    }
    
    
    
  public function deletep(Request $request)
    {
  DB::table('invgoods')->where('id',  $request->input('productid'))->limit(1)->delete();
  DB::table('invstock')->where('productid',  $request->input('productid'))->delete();
$response = [ 'success'=>true, 'message'=> 'deleted retrieved successfully' ];
    return response()->json($response,200);     
    }
    
  public function deletepp(Request $request)
    {
  DB::table('invstock')->where('id',  $request->input('productid'))->delete();
    }    
    
        public function suppliers()
    {
        
        //$goods = DB::table('invstock')->unique('supliername')->get();
        $goods = DB::table('invstock')->select('supliername' )->distinct()->get();
        //$goods = DB::select("SELECT * FROM invstock GROUP BY supliername")->get();
        if (empty($goods)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $goods,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }  
    
    

    
   public function customers($id)
    {
        
        //$goods = DB::table('invstock')->unique('supliername')->get();
        $goods = DB::table('invcustomers')->where('type',  $id)->get();
        //$goods = DB::select("SELECT * FROM invstock GROUP BY supliername")->get();
        if (empty($goods)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $goods,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }
    
    
    
    public function getcompany($id)
    {
        
        //$goods = DB::table('invstock')->unique('supliername')->get();
        $goods = DB::table('invcompany')->where('iduser',  $id)->get();
        //$goods = DB::select("SELECT * FROM invstock GROUP BY supliername")->get();
        if (empty($goods)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $goods,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }   
      
      
      
      
      
      
      
      
      
 public function editcompany(Request $request){
             DB::table('invcompany')->where('id',  $request->input('id'))
             ->update(
                 array(
                        'name' => $request->input('name') , 
                        'address' => $request->input('address'),
                        'email' => $request->input('email') , 
                        'taxid' => $request->input('taxid'),
                        'bank' => $request->input('bank') , 
                        'phone' => $request->input('phone') , 
                        'iduser' => $request->input('iduser'),
                     ));  
                     
        $categories = DB::table('invcompany')->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);               
                     
                     
 }      
      
      
      
      
      
      
 
      
      
      
       
 public function addcompany(Request $request)
    {
  
       
        DB::table('invcompany')->insert([
            'name' => $request->input('name') , 
            'address' => $request->input('address'),
            'email' => $request->input('email') , 
            'phone' => $request->input('phone') , 
            'taxid' => $request->input('taxid'),
            'bank' => $request->input('bank') , 
            'iduser' => $request->input('iduser'),
            'subscribe' => "unsubscribed",
             ]  );
        
  $categories = DB::table('invcompany')->where('iduser',$request->input('iduser'))->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];
           
          DB::table('invusers')->where('id',  $request->input('iduser'))
         ->update(
             array('idcompany' => $categories['0']->id )); 

        return response()->json($response,200);

    }     
    
    
    public function adduser(Request $request)
    {
  
        DB::table('invusers')->insert([
            'fname' => $request->input('fname') , 
            'lname' => $request->input('lname'),
            'tell' => $request->input('tell') , 
            'pwd' => $request->input('pwd'),
            'email' => $request->input('email') , 
            'rights' => $request->input('rights'),
            'idcompany' => $request->input('idcompany'),
             ]  );
        
  $categories = DB::table('invusers')->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);

    } 


 public function edituser(Request $request){
             DB::table('invusers')->where('id',  $request->input('id'))
             ->update(
                 array(
                    'fname' => $request->input('fname') , 
                    'lname' => $request->input('lname'),
                    'tell' => $request->input('tell') , 
                    'pwd' => $request->input('pwd'),
                    'email' => $request->input('email') , 
                    'rights' => $request->input('rights'),
                     ));  
                     
        $categories = DB::table('invcompany')->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);               
                     
                     
 }  


    
    
    public function getusers($id)
    {
        
        $goods = DB::table('invusers')->where('idcompany',  $id)->get();

        if (empty($goods)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $goods,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }  
    
     public function getuser($id)
    {
        
        $goods = DB::table('invusers')->where('id',  $id)->get();

        if (empty($goods)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $goods,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }    
    
    
    public function loginuser($tell , $pwd)
    {
        /*if($tell == '256779815657'){
           $goods = DB::table('invusers')->where([['tell',  $tell] , ['pwd',  $pwd]])->get(); 
        }else{
            
        }
        */
  $goods = DB::table('invusers')->where([['tell',  $tell] , ['pwd',  $pwd]])->get(); 
        if (empty($goods)) {
            return $this->sendError('User not found');
        }
        
         $categories = DB::table('invcompany')->where('iduser', $goods['0']->id )->get();
        
        
        $response = [
            'success'=>true,
            'data'=> $goods,
            'data2'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }  
    
    /*
    public function addcustomer(Request $request)
    {
  
        DB::table('invcustomer')->insert([
            'name' => $request->input('name') , 
            'customername' => $request->input('description'),
            'type' => $request->input('stock') , 
             ]  );
        
  $categories = DB::table('invcustomer')->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);

    } */ 
    
    
    
    /////////////////////////////add currency ///////////////////////////////////////////////////////////////
     public function addcurrency(Request $request)
    {

        DB::table('invcurrency')->insert([
            'name' => $request->input('name') , 
            'companyid' => $request->input('idcompany')
             ]  );
        
  $categories = DB::table('invcurrency')->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];
           
        return response()->json($response,200);

    }
    
    
    /////////////////////////////get  currency ///////////////////////////////////////////////////////////////
    public function currency($id)
    {
        
        $categories = DB::table('invcurrency')->where('companyid','=', $id)->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }
    
    /////////////////////////////add units ///////////////////////////////////////////////////////////////
    public function addunits(Request $request)
    {

        DB::table('invunits')->insert([
            'name' => $request->input('name') , 
            'companyid' => $request->input('idcompany')
             ]  );
        
  $categories = DB::table('invunits')->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];
           
         return response()->json($response,200);

    }
    
        /////////////////////////////get units ///////////////////////////////////////////////////////////////
    public function units($id)
    {
        
        $categories = DB::table('invunits')->where('companyid','=', $id)->get();
        if (empty($categories)) {
            return $this->sendError('User not found');
        }
        $response = [
            'success'=>true,
            'data'=> $categories,
            'message'=> 'User retrieved successfully'
           ];

        return response()->json($response,200);
    }
    
    
    //////////////////////////////////////////
    
    public function deletestore(Request $request)
    {
    DB::table('invstore')->where('id',  $request->input('id'))->limit(1)->delete();
    $response = [ 'success'=>true, 'message'=> 'deleted retrieved successfully' ];
    return response()->json($response,200);
    }
    
    public function deletecustomer(Request $request)
    {
    DB::table('invcustomers')->where('id',  $request->input('id'))->limit(1)->delete();
    $response = [ 'success'=>true, 'message'=> 'deleted retrieved successfully' ];
    return response()->json($response,200);
    }
    
    
    public function deletesupplier(Request $request)
    {
    DB::table('invcustomers')->where('id',  $request->input('id'))->limit(1)->delete();
    $response = [ 'success'=>true, 'message'=> 'deleted retrieved successfully' ];
    return response()->json($response,200);
    }
    
    
    public function deleteunit(Request $request)
    {
    DB::table('invunits')->where('id',  $request->input('id'))->limit(1)->delete();
    $response = [ 'success'=>true, 'message'=> 'deleted retrieved successfully' ];
    return response()->json($response,200);
    }
    
    public function deletecurrency(Request $request)
    {
    DB::table('invcurrency')->where('id',  $request->input('id'))->limit(1)->delete();
    $response = [ 'success'=>true, 'message'=> 'deleted retrieved successfully' ];
    return response()->json($response,200);
    }

    
}
