<?php

use Illuminate\Support\Facades\Route;
use Laravel\Socialite\Facades\Socialite;
/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    return view('auth.login');
});

Auth::routes();


Route::get('/admin-restriction', [App\Http\Controllers\HomeController::class, 'admin'])->name('admin-restriction');


Route::get('/home', [App\Http\Controllers\HomeController::class, 'index'])->name('home');

Route::group(['middleware' => 'admin'], function () {


    Route::resource('roles', App\Http\Controllers\RoleController::class);
    Route::resource('permissions', App\Http\Controllers\PermissionController::class);
    Route::resource('sliders', App\Http\Controllers\SliderController::class);
    Route::resource('countries', App\Http\Controllers\CountryController::class);
    Route::resource('districts', App\Http\Controllers\DistrictController::class);
    Route::resource('farms', App\Http\Controllers\FarmController::class);
    Route::resource('categories', App\Http\Controllers\CategoryController::class);
    Route::resource('crops', App\Http\Controllers\CropController::class);
    Route::resource('plots', App\Http\Controllers\PlotController::class);
    Route::resource('expenseCategories', App\Http\Controllers\ExpenseCategoryController::class);
    Route::resource('expenses', App\Http\Controllers\ExpenseController::class);
    Route::resource('harvests', App\Http\Controllers\HarvestController::class);
    Route::resource('companies', App\Http\Controllers\CompanyController::class);
    Route::resource('subCategories', App\Http\Controllers\SubCategoryController::class);
    Route::resource('sellerProductCategories', App\Http\Controllers\SellerProductCategoryController::class);
    Route::resource('sellerProducts', App\Http\Controllers\SellerProductController::class);
    Route::resource('farmers', App\Http\Controllers\UserController::class);
    Route::get('buyers', [App\Http\Controllers\UserController::class, 'buyers'])->name('buyers');

    //sellers
    Route::get('sellers', [App\Http\Controllers\SellerController::class, 'index'])->name('sellers.index');
    Route::get('sellers/create', [App\Http\Controllers\SellerController::class, 'create'])->name('sellers.create');
    Route::get('sellers/{id}', [App\Http\Controllers\SellerController::class, 'show'])->name('sellers.show');
    Route::get('sellers/{id}/edit', [App\Http\Controllers\SellerController::class, 'edit'])->name('sellers.edit');
    Route::put('sellers/update', [App\Http\Controllers\SellerController::class, 'update'])->name('sellers.update');
    Route::post('sellers/new', [App\Http\Controllers\SellerController::class, 'store'])->name('sellers.store');
    Route::delete('sellers/{id}', [App\Http\Controllers\SellerController::class, 'destroy'])->name('sellers.destroy');


    //buyers
    Route::get('buyers', [App\Http\Controllers\BuyerController::class, 'index'])->name('buyers.index');
    Route::get('buyers/create', [App\Http\Controllers\BuyerController::class, 'create'])->name('buyers.create');
    Route::get('buyers/{id}', [App\Http\Controllers\BuyerController::class, 'show'])->name('buyers.show');
    Route::get('buyers/{id}/edit', [App\Http\Controllers\BuyerController::class, 'edit'])->name('buyers.edit');
    Route::put('buyers/update', [App\Http\Controllers\BuyerController::class, 'update'])->name('buyers.update');
    Route::post('buyers/new', [App\Http\Controllers\BuyerController::class, 'store'])->name('buyers.store');
    Route::delete('buyers/{id}', [App\Http\Controllers\BuyerController::class, 'destroy'])->name('buyers.destroy');


    Route::resource('cropBuyers', App\Http\Controllers\CropOrderController::class);
    Route::resource('cropOnSales', App\Http\Controllers\CropOnSaleController::class);
    Route::resource('cropBuyers', App\Http\Controllers\CropOrderController::class);
    Route::resource('vendorCategories', App\Http\Controllers\VendorCategoryController::class);
    Route::resource('traningVendorServices', App\Http\Controllers\TraningVendorServiceController::class);
    Route::resource('farmerTrainings', App\Http\Controllers\FarmerTrainingController::class);

 });



//google login

Route::get('/auth/google/redirect', function () {
    return Socialite::driver('google')->redirect();
});

Route::get('/auth/google/callback',[App\Http\Controllers\GoogleRegisterController::class,'googleCallback'])->name('google-register');



Route::resource('trials', App\Http\Controllers\TrialController::class);


Route::resource('cropHarvests', App\Http\Controllers\CropHarvestController::class);


Route::resource('cropOnSales', App\Http\Controllers\CropOnSaleController::class);


Route::resource('cropOrders', App\Http\Controllers\CropOrderController::class);


Route::resource('trainingVendorServices', App\Http\Controllers\TrainingVendorServiceController::class);


Route::resource('farmerTrainings', App\Http\Controllers\FarmerTrainingController::class);


Route::resource('animalFeedCategories', App\Http\Controllers\AnimalFeedCategoryController::class);


Route::resource('animalFeedSubCategories', App\Http\Controllers\AnimalFeedSubCategoryController::class);


Route::resource('animalFeeds', App\Http\Controllers\AnimalFeedController::class);







Route::get('showaddcateg', [App\Http\Controllers\UserController::class, 'showaddcateg'])->name('showaddcateg');
Route::post('addcateg', [App\Http\Controllers\UserController::class, 'addcateg'])->name('addcateg');
Route::post('deletecateg', [App\Http\Controllers\UserController::class, 'deletecateg'])->name('deletecateg');

Route::get('addproduct', [App\Http\Controllers\UserController::class, 'addproduct'])->name('addproduct');
Route::post('saveproduct', [App\Http\Controllers\UserController::class, 'saveproduct'])->name('saveproduct');

Route::post('deleteproduct', [App\Http\Controllers\UserController::class, 'deleteproduct'])->name('deleteproduct');



Route::get('addproductvendor', [App\Http\Controllers\UserController::class, 'addproductvendor'])->name('addproductvendor');
Route::post('savevendorprice', [App\Http\Controllers\UserController::class, 'savevendorprice'])->name('savevendorprice');
